@@ -2,7 +2,7 @@ package Mail::MtPolicyd::Connection::Redis;
 
 use Moose;
 
-our $VERSION = '2.01'; # VERSION
+our $VERSION = '2.02'; # VERSION
 # ABSTRACT: a mtpolicy connection for redis databases
 
 extends 'Mail::MtPolicyd::Connection';
@@ -18,7 +18,7 @@ has 'db' => ( is => 'ro', isa => 'Int', default => 0 );
 sub _create_handle {
   my $self = shift;
   my $redis = Redis->new(
-    'server' => $self->servers,
+    'server' => $self->server,
     'debug' => $self->debug,
     defined $self->password ? ( 'password' => $self->password ) : (),
   );
@@ -42,7 +42,8 @@ sub reconnect {
 
 sub shutdown {
   my $self = shift;
-  $self->handle->disconnect_all;
+  $self->handle->wait_all_responses;
+  $self->handle->quit;
   return;
 }
 
@@ -60,7 +61,7 @@ Mail::MtPolicyd::Connection::Redis - a mtpolicy connection for redis databases
 
 =head1 VERSION
 
-version 2.01
+version 2.02
 
 =head1 SYNOPSIS
 
