@@ -2,9 +2,10 @@ package Mail::MtPolicyd::SessionCache::Redis;
 
 use Moose;
 
-our $VERSION = '2.01'; # VERSION
+our $VERSION = '2.02'; # VERSION
 # ABSTRACT: a session cache adapter for redis
 
+use Time::HiRes qw(usleep);
 use Storable;
 
 extends 'Mail::MtPolicyd::SessionCache::Base';
@@ -56,7 +57,7 @@ sub retrieve_session {
 
 	if( my $blob = $self->_redis_handle->get($instance) ) {
     my $session;
-    eval { $session = Storage::thaw( $blob ) };
+    eval { $session = Storable::thaw( $blob ) };
     if( $@ ) {
       die("could not restore session $instance: $@");
     }
@@ -96,7 +97,7 @@ Mail::MtPolicyd::SessionCache::Redis - a session cache adapter for redis
 
 =head1 VERSION
 
-version 2.01
+version 2.02
 
 =head1 SYNOPSIS
 
